import { BaseSDK } from './sdk';
import { Router, StandardResponse, ResponseType } from '@jolibox/types';
/**
 * @private
 * Provides routing and navigation functionalities within the Jolibox SDK.
 * This includes opening schemas, web pages, and navigating to native application pages.
 * @implements {Router}
 */
export declare class RouterSDK extends BaseSDK implements Router {
    /**
     * @public
     * Opens a given schema URL.
     * This is often used for deep linking or triggering specific actions within the host application or other apps.
     * @param schema - The schema URL string to open (e.g., 'yourapp://action?param=value').
     * @returns A promise that resolves with a StandardResponse, or an error object if the capability is not available.
     */
    openSchema(schema: string): Promise<StandardResponse<void> | {
        code: ResponseType;
        message: string;
    }>;
    /**
     * @public
     * Opens a web page in a new view (e.g., an in-app browser or a new tab).
     * @param url - The URL of the web page to open.
     * @returns A promise that resolves with a StandardResponse containing the webviewId, or an error object if the capability is not available.
     */
    openPage(url: string): Promise<StandardResponse<{
        webviewId: number;
    }> | {
        code: ResponseType;
        message: string;
    }>;
    /**
     * @public
     * Closes a previously opened web page/view, identified by its webviewId.
     * @param webviewId - The ID of the webview to close.
     * @returns A promise that resolves with a StandardResponse, or an error object if the capability is not available.
     */
    closePage(webviewId: number): Promise<StandardResponse<void> | {
        code: ResponseType;
        message: string;
    }>;
    /**
     * @public
     * Intercepts the system's back button or exit gesture.
     * @param intercept - A boolean indicating whether to intercept the exit (true) or allow default behavior (false).
     * @returns A promise that resolves with a StandardResponse, or an error object if the capability is not available.
     */
    interceptSystemExit(intercept: boolean): Promise<StandardResponse<void> | {
        code: ResponseType;
        message: string;
    }>;
    /**
     * @public
     * Navigates to a specific native page within the host application.
     * @param path - The identifier for the native page to navigate to. Currently, only 'openHistory' is explicitly supported by this client-side check.
     * @param params - A record of parameters to pass to the native page.
     * @returns A promise that resolves with a StandardResponse, or an error object if the capability is not available or the path is invalid.
     */
    navigateToNativePage(path: string, params: Record<string, unknown>): Promise<StandardResponse<void> | {
        code: ResponseType;
        message: string;
    }>;
}
